<?php
/**
 * @package MiGCMS
 * @author Justin C. Klein Keane <justin@madirish.net>
 * @version 2.0
 *
 * @abstract This is the controller page for the content module (the material displayed on the front end of the website).
 *
 * @todo add logging
 */
require_once('lib/util/display.class.php');
require_once('lib/obj/collection.class.php');
require_once('lib/obj/section.class.php');

$app_path = $GLOBALS['application']['app_root'];
$GLOBALS['smarty_config']['template_dir'] = 'inc/modules/content/inc/templates';
$GLOBALS['smarty_config']['cache_dir'] = 'inc/modules/content/inc/templates/cached';
$GLOBALS['smarty_config']['compile_dir'] = 'inc/modules/content/inc/templates/compiled';

$display = new Display();
$display->assign('site_title', $GLOBALS['site']['title']);

$section_id = isset($_GET['section_id']) ? intval($_GET['section_id']) : 0;
$content_id = isset($_GET['content_id']) ? intval($_GET['content_id']) : 0;

//silently reset the module for easy URL's
if ($section_id > 0) {
	$_GET['submodule'] = 'section';
}
if ($content_id > 0) {
	$_GET['submodule'] = 'content';
}

$top_level_sections = new Collection('section', 'where section_active = 1 AND section_parent_id = 0');

//set up the super nav array
$top_section_display = '';
if (is_array($top_level_sections->members)) {
	foreach($top_level_sections->members as $section) {
		$top_section_display[] = array('section_id' => $section->section_id,
									'section_title' => $section->section_title);
	}
}



$submodule = isset($_GET['submodule']) ? $_GET['submodule'] : 'index';


if(file_exists('inc/modules/content/inc/' . $submodule . '.php')) {
	include_once('inc/modules/content/inc/' . $submodule . '.php');
}
else {
	include_once('inc/modules/content/inc/index.php');
}

//display the content
$date = getdate();

$display->assign('year', $date['year']);
$display->assign('owner', $GLOBALS['application']['app_owner']);
$display->assign('owner_email', $GLOBALS['application']['app_owner_email']);
$display->assign('app_path', $app_path);
$display->assign('section1', $top_section_display);
$display->show_template('default');

log_view($submodule, $content_id, $section_id);

/*****************************************************************

				Local Functions

*****************************************************************/

function breadcrumb($id) {
	$bc_section = new Section($id);
	$uplist[0] = array('section_id' => $bc_section->section_id, 'section_title' => $bc_section->section_title);

	while ($bc_section->section_parent_id !== '0') {
		$bc_section = new Section($bc_section->section_parent_id);
		$uplist[] = array('section_id' => $bc_section->section_id, 'section_title' => $bc_section->section_title);
	}


	$uplist[] = array('section_id' => '0', 'section_title' => 'Top');
	//flip the values
	$y=0;
	for ($x=count($uplist);$x>0;$x--) {
		$retval[$y] = $uplist[$x-1];
		$y++;
	}
	return $retval;
}

/**
 * Log the usage for later.
 *
 * @param string $type
 * @param text $text
 */
function log_view($page, $id, $section) {
		global $db;
		require_once('lib/obj/usage_log.class.php');
		$log = new Usage_Log();
		$log->usage_log_remote_addr = $_SERVER['REMOTE_ADDR'];
		if (isset($_SERVER['HTTP_REFERER'])) {
			$log->usage_log_referer = $_SERVER['HTTP_REFERER'];
		}
		$log->usage_log_user_agent = $_SERVER['HTTP_USER_AGENT'];
		$log->usage_log_page = $page;
		$log->usage_log_content_id = $id;
		$log->usage_log_section_id = $section;

		$log->set($db);
}
?>