<?php
/**
 * @package MiGCMS
 * @author Justin C. Klein Keane <justin@madirish.net>
 * @version 0.1
 *
 * @abstract <p>Collection is simply a factory class.</p>
 * <p>This class builds a collection of objects based on strict rules and the name passed in.  The name must match the object class name as well as database naming convention exactly.  For instance, to create a new collection of 'ants' objects using:</p><p><pre>
 * $ant_collection = new Collection('ant');
 * </pre></p><p>
 * The file /admin/lib/obj/ant.class.php must exist, there must be a table named 'ant' in the database with the primary key ant_id.  If these conditions are met then the class will poll the database with 'select ant_id from ant' and use the id's to instantiate new ant classes for each id.  These will be assigned to a return array that will be passed back.
 *
 * @todo
 */

require_once($GLOBALS['application']['app_root'] . 'lib/util/db_object.class.php');

Class Collection extends DB_Object {

	/**
	 * $members is an array of objects collected by the __construct().
	 *
	 * @var array
	 */
	var $members;

	/**
	 * The construct accepts a string that is used to determine the primary key, table name, PHP script name, and object name that will be used to create objects (which will then be added to the $members variable.
	 *
	 * @param string $collection_name
	 */
	function __construct($collection_name,$filter='') {
		parent::__construct();

		//locate our file
		if (! isset($GLOBALS['application']['app_root'])) {
			$app_path = explode('/', $_SERVER['PHP_SELF']);
			$inc_path = $_SERVER['DOCUMENT_ROOT'] . '/' . $app_path[1] . '/';
		}
		else {
			$inc_path = $GLOBALS['application']['app_root'];
		}

		require_once ($inc_path . 'lib/obj/' . $collection_name . '.class.php');
		//look up the collection in data definitions
		$definition = new $collection_name;
		$data_definition = $definition->get_definition($filter);

		$collection = $this->get_all($data_definition);
		$id = $collection_name . '_id';

		foreach ($collection as $item) {
			$this->members[] = new $collection_name($item[$id]);
		}

	}
}
?>