<?php
/**
 * @package MiGCMS
 * @author Justin C. Klein Keane <justin@madirish.net>
 * @version 2.0
 *
 * @abstract This is a wrapper class for Smarty.  Derived from the fileManipLib.php of MiGCMS version 1, this class is used to move files up to the server.
 *
 * @todo
 */

/*
Legacy comment:
fileManipLib.php
Author: Justin C. Klein Keane
Organization: Mad Irish Group, LLC
Description:  This file includes class libraries for manipulating and uploading files.
Created: Feb 03, 2005 09:00
Last Updated: June 30, 2006 13:00
*/

Class File_Upload {

		/**
		 * This is the name of the form field passed in for processing
		 *
		 * @var string
		 */
		var $formField;

		/**
		 * Array of allowable file extensions in the format '.gif'.  This should map one to one with the $extensiontypes array.
		 *
		 * @var array
		 */
		var $allowExtensions = array();

		/**
		 * Acceptable extensions for allowed file types, in the format 'image' or 'file'
		 *
		 * @var array
		 */
		var $extensionTypes = array();

		/**
		 * This variable is used to track redirects after processing
		 *
		 * @var string
		 */
		var $pageURL;

		/**
		 * The file extension of the file for processing
		 *
		 * @var string
		 */
		var $fileExtension;

		/**
		 * Type of upload, either file or image
		 *
		 * @var string
		 */
		var $uploadType;

		/**
		 * if set to yes will run the image resize function
		 *
		 * @var string
		 */
		var $imageResize = "no";

		/**
		 * image resize height
		 *
		 * @var integer
		 */
		var $height;

		/**
		 * image resize width
		 *
		 * @var integer
		 */
		var $width; //image resize width

		/**
		 * If set to yes will enforce width/height for smaller images.
		 *
		 * @var string
		 */
		var $resizeUp = "no";

		/**
		 * The full relative filename
		 *
		 * @var string
		 */
		var $upload_filename;

		/**
		 * The full array of the $_FILES field from the posted form.
		 *
		 * @var array
		 */
		var $upload_item;

		/**
		 * Target for file uploads, if set it can override the defaults specified in the config.ini file.
		 *
		 * @var string
		 */
		var $uploadTarget;

		/**
		 * The filename of the uploaded file.
		 *
		 * @var string
		 */
		var $filename;

		/**
		 * Type, determined by doType()
		 *
		 * @var string
		 */
		var $type;

		function __construct($file) {
			$this->upload_item = $file;
		}

		/**
		 * This function will map the type of extension based on the $allowExtensions array and $extensionTypes array.  Once a match is found it will set the internal property $fileExtension to the extension and return the file type.
		 *
		 * @return unknown
		 */
		function doType() {
			if (count($this->allowExtensions) != count($this->extensionTypes)) {
				die ("File types and extensions must match in number");
			}
			$fileName = $this->upload_item[$this->formField]['name'];
			$extension = strtolower(substr($fileName, -4));
			$typeFinder = array_search($extension, $this->allowExtensions);
			if ($typeFinder === FALSE) {
				$type = "unknown";
			}
			else {
				$extension = $this->allowExtensions[$typeFinder];
				$type = $this->extensionTypes[$typeFinder];
			}
			if ($type == "unknown")
				{
				//die (header("Location:" . $this->pageURL . "?error=yes&ext=" . $extension));
				}
			$this->fileExtension = $extension;
			$this->type = $type;
			return $type;
		}

		/**
		 * Based on the type of upload this function will move the target file to the specified target directory on the server, governed by the uploads section of the config.ini file.
		 *
		 */
		function doUpload() {
			if ($this->uploadType == "image") {
				if (! isset($this->uploadTarget)) {
					$uploadTarget = $GLOBALS['uploads']['upload_img_dir'];
				}
				else {
					$uploadTarget = $this->uploadTarget;
				}
				$prepend = $GLOBALS['uploads']['file_prefix'];
			}
			else {
				if (! isset($this->uploadTarget)) {
					$uploadTarget = $this->uploadTarget;
				}
				else {
					$uploadTarget = $GLOBALS['uploads']['upload_file_dir'];
				}
				$prepend = $GLOBALS['uploads']['file_prefix'];
			}

			$tmp_name = $this->upload_item[$this->formField]['tmp_name'];
			$this->filename = $prepend  . time() . $this->fileExtension;
			$uploadfile = $uploadTarget . $this->filename;
			if (move_uploaded_file($this->upload_item[$this->formField]['tmp_name'], $uploadfile)) {
			   chmod($uploadfile, 0664);
			   $this->upload_filename = $uploadfile;
			}
			else {
			  $error = $this->defineError($HTTP_POST_FILES[$this->formField]['error']);
			  die("! " . $error);
			}
		}

		/**
		 * This is an error reporting function to translate upload error codes into friendlier messages.
		 *
		 * @param integer $error
		 * @return string
		 */
		function defineError($error){
 			switch($error){
			   case 0: //no error; possible file attack!
			     return "Error:  There was a problem with your upload.";
			     break;
			   case 1: //uploaded file exceeds the upload_max_filesize directive in php.ini
			     return "Error:  The file you are trying to upload is too big for server configuration.";
			     break;
			   case 2: //uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the html form
			     return "Error:  The file you are trying to upload is too big for html configuration.";
			     break;
			   case 3: //uploaded file was only partially uploaded
			     return "Error:  The file you are trying upload was only partially uploaded.";
			     break;
			   case 4: //no file was uploaded
			     return "Error:  You must select a file for upload.";
			     break;
			   default: //a default error, just in case!  :)
			     return "Error:  There was a problem with your upload.";
			     break;
				 }
			}

		/**
		 * This function will create a resized (.jpg) image out of the uploaded image file.  The method returns the filename of the uploaded image.
		 *
		 * @return string
		 */
		function makeThumb() {
				$gallery_dir = $GLOBALS['uploads']['upload_img_dir'];
				$thumbnail_dir = $GLOBALS['uploads']['upload_thumb_dir'];

				$thumbimage = $thumbnail_dir . $this->filename;

				copy($this->upload_filename, $thumbimage) or die("Moving file to thumbnail location for resize failed.");

				$max_width = $this->width;
				$max_height = $this->height;

				$size = GetImageSize($thumbimage);
				$width = $size[0];
				$height = $size[1];

				$x_ratio = $max_width / $width;
				$y_ratio = $max_height / $height;
				if (($this->imageResize == 'yes') || ($width > $max_width) || ($height > $max_height)) {
						if (($x_ratio > 0) && ($y_ratio > 0)) {
							//set w/h to current values
							$tn_width = $width;
							$tn_height = $height;
							if ($this->resizeUp == 'yes') {
								if (($x_ratio < 1) && ($y_ratio < 1)) {
									$tn_width = $width * $y_ratio;
									$tn_height = $height * $y_ratio;
								}
							}
							else {
									$tn_width = $width * $x_ratio;
									$tn_height = $height * $x_ratio;

							}
						}
						else if (($x_ratio * $height) < $max_height) {
						  $tn_height = ceil($x_ratio * $height);
						  $tn_width = $max_width;
						}
						else {
						  $tn_width = ceil($y_ratio * $width);
						  $tn_height = $max_height;
						}
				  }
				  else {
				  	$tn_width = $width;
					$tn_height = $height;
				  }

				  //thumbnail images are always JPEGs
				if ($this->type == ".jpg") {
					$src = ImageCreateFromJpeg($thumbimage);
					$dst = ImageCreateTrueColor($tn_width,$tn_height);
					ImageCopyResampled($dst, $src, 0, 0, 0, 0, $tn_width,$tn_height,$width,$height);
					ImageJpeg($dst, $thumbimage, 100);
					ImageDestroy($src);
					ImageDestroy($dst);
				}
				else {
					$src = ImageCreateFromGif($thumbimage);
					$dst = ImageCreateTrueColor($tn_width,$tn_height);
					ImageCopyResampled($dst, $src, 0, 0, 0, 0, $tn_width,$tn_height,$width,$height);
					unlink($thumbimage);
					$thumbimage = substr($thumbimage,0,-4) . ".jpg";
					$this->filename = substr($this->filename,0,-4) . ".jpg";
					ImageJpeg($dst, $thumbimage, 100);
					ImageDestroy($src);
					ImageDestroy($dst);
				}
				return $this->filename;

		}
}
?>